#pragma once

#include <iostream>

#include "fasttext/fasttext.h"
#include "fasttext/args.h"

int main(int argc, char** argv);
